use uom::si::electric_potential::volt;
use uom::si::electrical_resistance::ohm;
use uom::si::quantities::{ElectricPotential, ElectricalResistance};

/// Given the resistance of the second resistor in a resistive voltage divider, calculate the resistance of the first resistor.
pub fn solve_r1(
    voltage_src: ElectricPotential<f32>,
    voltage_read: ElectricPotential<f32>,
    r2: ElectricalResistance<f32>,
) -> ElectricalResistance<f32> {
    let volts_src = voltage_src.get::<volt>();
    let volts_read = voltage_read.get::<volt>();
    let ohms2 = r2.get::<ohm>();
    
    let ohms1 = ohms2 * (volts_src / volts_read - 1.0);
    ElectricalResistance::new::<ohm>(ohms1)
}

/// Given the resistance of the first resistor in a resistive voltage divider, calculate the resistance of the second resistor.
pub fn solve_r2(
    voltage_src: ElectricPotential<f32>,
    voltage_read: ElectricPotential<f32>,
    r1: ElectricalResistance<f32>,
) -> ElectricalResistance<f32> {
    let volts_src = voltage_src.get::<volt>();
    let volts_read = voltage_read.get::<volt>();
    let ohms1 = r1.get::<ohm>();
    
    let ohms2 = ohms1 * (1.0  / (volts_src / volts_read) - 1.0);
    ElectricalResistance::new::<ohm>(ohms2)
}
